<?php

namespace Drupal\tlsrpt\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implements a SecureLogin Config form.
 */
class TlsrptConfigForm extends ConfigFormBase {

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * Constructs an IpAnonSettings object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, DateFormatterInterface $date_formatter) {
    parent::__construct($config_factory);
    $this->dateFormatter = $date_formatter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('date.formatter')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tlsrpt_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tlsrpt.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $intervals = [
      -1,
      86400 * 365,
      86400 * 270,
      86400 * 180,
      86400 * 120,
      86400 * 90,
      86400 * 60,
      86400 * 30,
      86400 * 28,
      86400 * 21,
      86400 * 14,
      86400 * 7,
      86400 * 6,
      86400 * 5,
      86400 * 4,
      86400 * 3,
      86400 * 2,
      86400 * 1,
    ];
    $options = array_combine($intervals, array_map([
      $this->dateFormatter,
      'formatInterval',
    ], $intervals));
    $options[-1] = $this->t('Preserve forever');
    $form['ttl'] = [
      '#type'          => 'select',
      '#title'         => $this->t('TLSRPT report TTL'),
      '#options'       => $options,
      '#default_value' => $this->config('tlsrpt.settings')->get('ttl'),
      '#description'   => $this->t('Delete TLSRPT reports older than this interval.'),
    ];
    $form['mail'] = [
      '#type'          => 'email',
      '#title'         => $this->t('Email address'),
      '#default_value' => $this->config('tlsrpt.settings')->get('mail'),
      '#description'   => $this->t('If specified, this email address will be alerted when failure reports are received.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('tlsrpt.settings')
      ->set('ttl', $form_state->getValue('ttl'))
      ->set('mail', $form_state->getValue('mail'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
